"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Env = void 0;
const process_1 = require("../adapter/process");
const dotenv_1 = require("../adapter/dotenv");
class Env {
    path;
    data = new Map();
    static create(path) {
        const instance = new Env();
        instance.path = path;
        const data = dotenv_1.Dotenv.load(path);
        for (const name in data) {
            if (data[name] !== undefined) {
                instance.data.set(name, data[name]);
            }
        }
        return instance;
    }
    updateDefaultValue(keys) {
        for (const key of keys) {
            if (!this.data.has(key.name) && key.default !== undefined) {
                this.data.set(key.name, key.default);
            }
        }
        return this;
    }
    castingAllValue(keys) {
        const errorMessages = [];
        for (const key of keys) {
            const originalValue = this.data.get(key.name);
            if (originalValue === undefined) {
                // not found error
                if (key.nullable) {
                    this.data.set(key.name, null);
                }
                else {
                    errorMessages.push(`ERROR: ${this.path} - "${key.name}" is not defined`);
                }
                continue;
            }
            const castedValue = this.castingValue(originalValue, key);
            if (castedValue === undefined) {
                // type casting error
                errorMessages.push(`ERROR: ${this.path} - "${key.name}" is not allowed`);
                continue;
            }
            this.data.set(key.name, castedValue);
        }
        if (errorMessages.length >= 1)
            process_1.Process.kill(errorMessages);
        return this;
    }
    // eslint-disable-next-line @typescript-eslint/ban-types
    toUserEnvClass(userEnvClass) {
        for (const key of this.data.keys()) {
            userEnvClass[key] = this.data.get(key);
        }
        return this;
    }
    castingValue(value, key) {
        value = String(value);
        switch (key.type) {
            case Boolean:
                if (value === 'true')
                    return true;
                else if (value === 'false')
                    return false;
                else
                    return undefined;
            case Number:
                const castedValue = key.type(value);
                if (isNaN(castedValue))
                    return undefined;
                else
                    return castedValue;
            default:
                return key.type(value);
        }
    }
}
exports.Env = Env;
//# sourceMappingURL=env.js.map